@@ -68,7 +68,7 @@ class Filesystem(GenericFilesystem):
             if conf.direct or isTechniqueAvailable(PAYLOAD.TECHNIQUE.UNION):
                 if not kb.bruteMode:
                     warnMsg += ", going to fall-back to simpler UNION technique"
-                    logger.warn(warnMsg)
+                    logger.warning(warnMsg)
                 result = self.nonStackedReadFile(remoteFile)
             else:
                 raise SqlmapNoneDataException(warnMsg)
@@ -100,7 +100,7 @@ class Filesystem(GenericFilesystem):
             warnMsg += "to be written hexadecimal value is %d " % fcEncodedStrLen
             warnMsg += "bytes, this might cause errors in the file "
             warnMsg += "writing process"
-            logger.warn(warnMsg)
+            logger.warning(warnMsg)
 
         debugMsg = "exporting the %s file content to file '%s'" % (fileType, remoteFile)
         logger.debug(debugMsg)
@@ -129,7 +129,7 @@ class Filesystem(GenericFilesystem):
             warnMsg += "to be written hexadecimal value is %d " % fcEncodedStrLen
             warnMsg += "bytes, this might cause errors in the file "
             warnMsg += "writing process"
-            logger.warn(warnMsg)
+            logger.warning(warnMsg)
 
         debugMsg = "exporting the %s file content to file '%s'" % (fileType, remoteFile)
         logger.debug(debugMsg)
