@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2021 sqlmap developers (https://sqlmap.org/)
+Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -95,36 +95,45 @@ def _oneShotUnionUse(expression, unpack=True, limited=False):
         # Perform the request
         page, headers, _ = Request.queryPage(payload, content=True, raise404=False)
 
+        if page and kb.chars.start.upper() in page and kb.chars.start not in page:
+            singleTimeWarnMessage("results seems to be upper-cased by force. sqlmap will automatically lower-case them")
+
+            page = page.lower()
+
         incrementCounter(PAYLOAD.TECHNIQUE.UNION)
 
         if kb.jsonAggMode:
-            if Backend.isDbms(DBMS.MSSQL):
-                output = extractRegexResult(r"%s(?P<result>.*)%s" % (kb.chars.start, kb.chars.stop), removeReflectiveValues(page or "", payload))
-                if output:
-                    try:
-                        retVal = ""
-                        fields = re.findall(r'"([^"]+)":', extractRegexResult(r"{(?P<result>[^}]+)}", output))
-                        for row in json.loads(output):
-                            retVal += "%s%s%s" % (kb.chars.start, kb.chars.delimiter.join(getUnicode(row[field] or NULL) for field in fields), kb.chars.stop)
-                    except:
-                        pass
-                    else:
-                        retVal = getUnicode(retVal)
-            elif Backend.isDbms(DBMS.PGSQL):
-                output = extractRegexResult(r"(?P<result>%s.*%s)" % (kb.chars.start, kb.chars.stop), removeReflectiveValues(page or "", payload))
-                if output:
-                    retVal = output
-            else:
-                output = extractRegexResult(r"%s(?P<result>.*?)%s" % (kb.chars.start, kb.chars.stop), removeReflectiveValues(page or "", payload))
-                if output:
-                    try:
-                        retVal = ""
-                        for row in json.loads(output):
-                            retVal += "%s%s%s" % (kb.chars.start, row, kb.chars.stop)
-                    except:
-                        pass
-                    else:
-                        retVal = getUnicode(retVal)
+            for _page in (page or "", (page or "").replace('\\"', '"')):
+                if Backend.isDbms(DBMS.MSSQL):
+                    output = extractRegexResult(r"%s(?P<result>.*)%s" % (kb.chars.start, kb.chars.stop), removeReflectiveValues(_page, payload))
+                    if output:
+                        try:
+                            retVal = ""
+                            fields = re.findall(r'"([^"]+)":', extractRegexResult(r"{(?P<result>[^}]+)}", output))
+                            for row in json.loads(output):
+                                retVal += "%s%s%s" % (kb.chars.start, kb.chars.delimiter.join(getUnicode(row[field] or NULL) for field in fields), kb.chars.stop)
+                        except:
+                            retVal = None
+                        else:
+                            retVal = getUnicode(retVal)
+                elif Backend.isDbms(DBMS.PGSQL):
+                    output = extractRegexResult(r"(?P<result>%s.*%s)" % (kb.chars.start, kb.chars.stop), removeReflectiveValues(_page, payload))
+                    if output:
+                        retVal = output
+                else:
+                    output = extractRegexResult(r"%s(?P<result>.*?)%s" % (kb.chars.start, kb.chars.stop), removeReflectiveValues(_page, payload))
+                    if output:
+                        try:
+                            retVal = ""
+                            for row in json.loads(output):
+                                retVal += "%s%s%s" % (kb.chars.start, row, kb.chars.stop)
+                        except:
+                            retVal = None
+                        else:
+                            retVal = getUnicode(retVal)
+
+                if retVal:
+                    break
         else:
             # Parse the returned page to get the exact UNION-based
             # SQL injection output
@@ -158,7 +167,7 @@ def _oneShotUnionUse(expression, unpack=True, limited=False):
                 warnMsg = "possible server trimmed output detected "
                 warnMsg += "(probably due to its length and/or content): "
                 warnMsg += safecharencode(trimmed)
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
             elif re.search(r"ORDER BY [^ ]+\Z", expression):
                 debugMsg = "retrying failed SQL query without the ORDER BY clause"
@@ -295,7 +304,7 @@ def unionUse(expression, unpack=True, dump=False):
                 warnMsg += "of entries for the SQL query provided. "
                 warnMsg += "sqlmap will assume that it returns only "
                 warnMsg += "one entry"
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
                 stopLimit = 1
 
@@ -303,7 +312,7 @@ def unionUse(expression, unpack=True, dump=False):
                 if not count:
                     warnMsg = "the SQL query provided does not "
                     warnMsg += "return any output"
-                    logger.warn(warnMsg)
+                    logger.warning(warnMsg)
                 else:
                     value = []  # for empty tables
                 return value
@@ -420,7 +429,7 @@ def unionUse(expression, unpack=True, dump=False):
 
                     warnMsg = "user aborted during enumeration. sqlmap "
                     warnMsg += "will display partial output"
-                    logger.warn(warnMsg)
+                    logger.warning(warnMsg)
 
                 finally:
                     for _ in sorted(threadData.shared.buffered):
